# Color palette 
load("palette2.Rdata")
colpals_mod = colpals
colpals_mod[18,5] = "other"
m = match( levels(factor(naivecells2$predicted.celltype.l2)), colpals_mod[,2] )


# Subset object to naive cell types 
naivecells <- subset(obj[,filt ], predicted.celltype.l2 == "B naive" | predicted.celltype.l2 == "CD4 Naive" |  predicted.celltype.l2 == "CD8 Naive")
naivecells@active.assay = "integrated"

# Run dim reduction and clustering 
naivecells <- RunPCA(naivecells, verbose = FALSE)
naivecells <- RunUMAP(naivecells, reduction = "pca", dims = 1:15)
naivecells <- FindNeighbors(naivecells, reduction = "pca", dims = 1:15)
naivecells <- FindClusters(naivecells, resolution = 0.5)

# Visualizations
## UMAP
p1 <- DimPlot(naivecells, reduction = "umap", group.by = "timepoint")
p2 <- DimPlot(naivecells, reduction = "umap", group.by = "predicted.celltype.l2", label = TRUE, repel = TRUE)

# Redo removing VDJ and IG genes 
naivecells2 = naivecells 
countmatrix = naivecells2@assays$integrated@data
countmatrix2 = naivecells2@assays$integrated@scale.data


is_ig_vdj <- grepl("IG[HLK][VJ]", row.names(countmatrix))
is_ighd_vdj <- grepl("IGHD.-", row.names(countmatrix)) #so as to not drop IGHD constant regions
is_tr_vdj <- grepl("^TR[ABGD][VDJ]", row.names(countmatrix)) 


##removing the IG/TR VDJ genes from the count matrix
 naivecells2@assays$integrated@scale.data[(is_tr_vdj | is_ighd_vdj | is_ig_vdj), ] = 0
 naivecells2@assays$integrated@data[(is_tr_vdj | is_ighd_vdj | is_ig_vdj), ] = 0
 
 

# Run dim reduction and clustering 
naivecells2 <- RunPCA(naivecells2, verbose = FALSE)
naivecells2 <- RunUMAP(naivecells2, reduction = "pca", dims = 1:15)
naivecells2 <- FindNeighbors(naivecells2, reduction = "pca", dims = 1:15)
naivecells2 <- FindClusters(naivecells2, resolution = 0.5)



# Visualizations

## UMAP
p1 <- DimPlot(naivecells2, reduction = "umap", group.by = "timepoint")
p2 <- DimPlot(naivecells2, reduction = "umap", group.by = "predicted.celltype.l2", label = TRUE, repel = TRUE)
p3 <- DimPlot(naivecells2, reduction = "umap", group.by = "batch")
p4 <- DimPlot(naivecells2, reduction = "umap", group.by = "long.COVID", label = TRUE, repel = TRUE)



png("plots/combined_SCT_naivecells_redo.png",  width=1000)
p1 + p2
dev.off()


## Assess at timepoints
t24 = naivecells2$timepoint == "24months"
t4 = naivecells2$timepoint == "4months"
t8 = naivecells2$timepoint == "8months"

png("plots/final_naivecells_novdj_l2_split_t24.png",  height=1000, width=2000)
 DimPlot(naivecells2[,t24], reduction = "umap", split.by = "long.COVID", group.by = "predicted.celltype.l2", label = TRUE, repel = TRUE, cols=colpals_mod[m,3],  pt.size=2) + NoLegend() + plot_annotation(title="24 months")
dev.off()

png("plots/final_naivecells_novdj_l2_split_t4.png",  height=1000, width=2000)
 DimPlot(naivecells2[,t4], reduction = "umap", split.by = "long.COVID", group.by = "predicted.celltype.l2", label = TRUE, repel = TRUE, cols=colpals_mod[m,3],  pt.size=2) + NoLegend() + plot_annotation(title="4 months")
dev.off()

png("plots/final_naivecells_novdj_l2_split_t8.png",  height=1000, width=2000)
 DimPlot(naivecells2[,t8], reduction = "umap", split.by = "long.COVID", group.by = "predicted.celltype.l2", label = TRUE, repel = TRUE, cols=colpals_mod[m,3],  pt.size=2) + NoLegend() + plot_annotation(title="8 months")
dev.off()

 
 
## Assess cell type proportions 
## L2
props_t8 =  propeller(clusters=naivecells2$predicted.celltype.l2[t8], 
                      sample=naivecells2$Demuxlet_Individual_Assignment[t8], 
                      group=naivecells2$long.COVID[t8])


props_t4 =  propeller(clusters=naivecells2$predicted.celltype.l2[t4], 
                      sample=naivecells2$Demuxlet_Individual_Assignment[t4], 
                      group=naivecells2$long.COVID[t4])



props_t24 =  propeller(clusters=naivecells2$predicted.celltype.l2[t24], 
                      sample=naivecells2$Demuxlet_Individual_Assignment[t24], 
                      group=naivecells2$long.COVID[t24])


## L3
props_t8 =  propeller(clusters=naivecells2$predicted.celltype.l3[t8], 
                      sample=naivecells2$Demuxlet_Individual_Assignment[t8], 
                      group=naivecells2$long.COVID[t8])


props_t4 =  propeller(clusters=naivecells2$predicted.celltype.l3[t4], 
                      sample=naivecells2$Demuxlet_Individual_Assignment[t4], 
                      group=naivecells2$long.COVID[t4])


props_t24 =  propeller(clusters=naivecells2$predicted.celltype.l3[t24], 
                      sample=naivecells2$Demuxlet_Individual_Assignment[t24], 
                      group=naivecells2$long.COVID[t24])

        
# Assess other key markers 
goi = c ( "HLA-DRA", "HLA-DRB5", "HLA-DRB1", "CD38")
p1 <- FeaturePlot(object = naivecells2[,t4], features = goi, split.by = "long.COVID", reduction = "umap") #+ labs(title = "LC")
p2 <- FeaturePlot(object = naivecells2[,t8], features = goi, split.by = "long.COVID", reduction = "umap") #+ labs(title = "nLC")
p3 <- FeaturePlot(object = naivecells2[,t24], features = goi, split.by = "long.COVID", reduction = "umap") #+ labs(title = "nLC")


png("plots/final_naivecells_novdj_l2_split_t4_markers.png",  height=2000, width=1000)
p1 + plot_annotation(title="4 months")
dev.off()

png("plots/final_naivecells_novdj_l2_split_t8_markers.png",  height=2000, width=1000)
p2 + plot_annotation(title="8 months")
dev.off()
 
png("plots/final_naivecells_novdj_l2_split_t24_markers.png",  height=2000, width=1000)
p3 + plot_annotation(title="24 months")
dev.off()

 
png("plots/final_naivecells_novdj_l3_split_t24.png",  height=1000, width=2000)
 DimPlot(naivecells2[,t24], reduction = "umap", split.by = "long.COVID", group.by = "predicted.celltype.l3", label = TRUE, repel = TRUE,   pt.size=2) + NoLegend() + plot_annotation(title="24 months")
dev.off()

png("plots/final_naivecells_novdj_l3_split_t4.png",  height=1000, width=2000)
 DimPlot(naivecells2[,t4], reduction = "umap", split.by = "long.COVID", group.by = "predicted.celltype.l3", label = TRUE, repel = TRUE,   pt.size=2) + NoLegend() + plot_annotation(title="4 months")
dev.off()

png("plots/final_naivecells_novdj_l3_split_t8.png",  height=1000, width=2000)
 DimPlot(naivecells2[,t8], reduction = "umap", split.by = "long.COVID", group.by = "predicted.celltype.l3", label = TRUE, repel = TRUE,   pt.size=2) + NoLegend() + plot_annotation(title="8 months")
dev.off()

 
## Violin plots L2 
p1 <- VlnPlot(object = naivecells2[,t4], features = goi, stack=T, split.by = "long.COVID", group.by = "predicted.celltype.l2", col= c("red", "blue")) 
p2 <- VlnPlot(object = naivecells2[,t8], features = goi, stack=T, split.by = "long.COVID", group.by = "predicted.celltype.l2",  col= c("red", "blue")) 
p3 <- VlnPlot(object = naivecells2[,t24], features = goi, stack=T, split.by = "long.COVID", group.by = "predicted.celltype.l2",  col= c("red", "blue")) 
 
 
png("plots/final_naivecells_novdj_l2_split_t4_markers_vln.png",  height=800, width=600)
p1 + plot_annotation(title="4 months")
dev.off()

png("plots/final_naivecells_novdj_l2_split_t8_markers_vln.png",  height=800, width=600)
p2 + plot_annotation(title="8 months")
dev.off()
 
png("plots/final_naivecells_novdj_l2_split_t24_markers_vln.png",  height=800, width=600)
p3 + plot_annotation(title="24 months")
dev.off()


## Violin plots L3 
p1 <- VlnPlot(object = naivecells2[,t4], features = goi, stack=T, split.by = "long.COVID", group.by = "predicted.celltype.l3", col= c("red", "blue")) 
p2 <- VlnPlot(object = naivecells2[,t8], features = goi, stack=T, split.by = "long.COVID", group.by = "predicted.celltype.l3",  col= c("red", "blue")) 
p3 <- VlnPlot(object = naivecells2[,t24], features = goi, stack=T, split.by = "long.COVID", group.by = "predicted.celltype.l3",  col= c("red", "blue")) 
 
 
png("plots/final_naivecells_novdj_l3_split_t4_markers_vln.png",  height=800, width=600)
p1 + plot_annotation(title="4 months")
dev.off()

png("plots/final_naivecells_novdj_l3_split_t8_markers_vln.png",  height=800, width=600)
p2 + plot_annotation(title="8 months")
dev.off()
 
png("plots/final_naivecells_novdj_l3_split_t24_markers_vln.png",  height=800, width=600)
p3 + plot_annotation(title="24 months")
dev.off()

 
