# Cell proportions analysis 
library(speckle)
library(tidyverse)

# Proportion analysis based on sex (joint timepoints)
filt = metadata$Demuxlet_DropletType == "singlet" & metadata$percent.mt < 5
freq1 = plyr::count( cbind( metadata$Demuxlet_Individual_Assignment ,as.character(metadata$predicted.celltype.l2))[filt,] ) 
freq_sexp0 = spread(freq1, key = "x.2", value = "freq")
tenmp = t(freq_sexp0[ ,-1])
tenmp[is.na(tenmp)] = 0
tenmp = as.matrix(tenmp)
tempfrac0 = (sapply(1:dim(tenmp)[2], function(i) tenmp[,i]/sum(tenmp[,i], na.rm=T) ) )
colnames(tempfrac0) = freq_sexp0[,1]
m = match(colnames(tempfrac0), phens[,1] )
phens = phens[m,]
props0 =  propeller(clusters=metadata$predicted.celltype.l2[filt], sample=metadata$Demuxlet_Individual_Assignment[filt], group=metadata$Sex[filt])
m = match( rownames(tempfrac0),props0[,1]  )
props0= props0[m,]
save(props0, tempfrac0, freq_sexp0, file="propssex.l2.Rdata")
 
# Proportion analysis based on LC status
## Females
filt = metadata$Demuxlet_DropletType == "singlet" & metadata$percent.mt < 5 & metadata$Sex == "Female"
freq1 = plyr::count( cbind( metadata$Demuxlet_Individual_Assignment ,as.character(metadata$predicted.celltype.l2))[filt,] ) 
freq_sexp0 = spread(freq1, key = "x.2", value = "freq")
tenmp = t(freq_sexp0[ ,-1])
tenmp[is.na(tenmp)] = 0
tenmp = as.matrix(tenmp)
tempfrac0 = (sapply(1:dim(tenmp)[2], function(i) tenmp[,i]/sum(tenmp[,i], na.rm=T) ) )
colnames(tempfrac0) = freq_sexp0[,1]
m = match(colnames(tempfrac0), phens[,1] )
phens = phens[m,]
props0 =  propeller(clusters=metadata$predicted.celltype.l2[filt], sample=metadata$Demuxlet_Individual_Assignment[filt], group=metadata$long.COVID[filt])
m = match( rownames(tempfrac0),props0[,1]  )
props0= props0[m,]
save(props0, tempfrac0, freq_sexp0, file="propscovid_female.l2.Rdata")


## Males                   
filt = metadata$Demuxlet_DropletType == "singlet" & metadata$percent.mt < 5 & metadata$Sex == "Male"
freq1 = plyr::count( cbind( metadata$Demuxlet_Individual_Assignment ,as.character(metadata$predicted.celltype.l2))[filt,] ) 
freq_sexp0 = spread(freq1, key = "x.2", value = "freq")
tenmp = t(freq_sexp0[ ,-1])
tenmp[is.na(tenmp)] = 0
tenmp = as.matrix(tenmp)
tempfrac0 = (sapply(1:dim(tenmp)[2], function(i) tenmp[,i]/sum(tenmp[,i], na.rm=T) ) )
colnames(tempfrac0) = freq_sexp0[,1]
m = match(colnames(tempfrac0), phens[,1] )
phens = phens[m,]
props0 =  propeller(clusters=metadata$predicted.celltype.l2[filt], sample=metadata$Demuxlet_Individual_Assignment[filt], group=metadata$long.COVID[filt])
m = match( rownames(tempfrac0),props0[,1]  )
props0= props0[m,]
save(props0, tempfrac0, freq_sexp0, file="propscovid_male.l2.Rdata")

 
## Joint 
filt = metadata$Demuxlet_DropletType == "singlet" & metadata$percent.mt < 5
freq1 = plyr::count( cbind( metadata$Demuxlet_Individual_Assignment ,as.character(metadata$predicted.celltype.l2))[filt,] ) 
freq_sexp0 = spread(freq1, key = "x.2", value = "freq")
tenmp = t(freq_sexp0[ ,-1])
tenmp[is.na(tenmp)] = 0
tenmp = as.matrix(tenmp)
tempfrac0 = (sapply(1:dim(tenmp)[2], function(i) tenmp[,i]/sum(tenmp[,i], na.rm=T) ) )
colnames(tempfrac0) = freq_sexp0[,1]
m = match(colnames(tempfrac0), phens[,1] )
phens = phens[m,]
props0 =  propeller(clusters=metadata$predicted.celltype.l2[filt], sample=metadata$Demuxlet_Individual_Assignment[filt], group=metadata$long.COVID[filt])
m = match( rownames(tempfrac0),props0[,1]  )
props0= props0[m,]
save(props0, tempfrac0, freq_sexp0, file="propscovid.l2.Rdata")
 


# Proportions by sex and LC
freq1 = plyr:: count( obj$predicted.celltype.l2[ obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$Sex=="Male"] )
freq2 = plyr:: count( obj$predicted.celltype.l2[ obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$Sex=="Female"] )
freq = plyr:: count( obj$predicted.celltype.l2 [obj$MajoritySinglet_Individual_Assignment != "unassigned"])
freqLC = plyr:: count( obj$predicted.celltype.l2 [obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$long.COVID=="Yes" ])
freqNC = plyr:: count( obj$predicted.celltype.l2 [obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$long.COVID=="No" ])
freqLC1 = plyr:: count( obj$predicted.celltype.l2 [obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$long.COVID=="Yes" & obj$Sex=="Male" ])
freqNC1 = plyr:: count( obj$predicted.celltype.l2 [obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$long.COVID=="No" & obj$Sex=="Male" ])
freqLC2 = plyr:: count( obj$predicted.celltype.l2 [obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$long.COVID=="Yes" & obj$Sex=="Female" ])
freqNC2 = plyr:: count( obj$predicted.celltype.l2 [obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$long.COVID=="No" & obj$Sex=="Female" ])
m = match(freq[,1] , freq2[,1])
freq_sex_cell = cbind(freq, freq1[,2], freq2[m,2] ,freqLC[m,2], freqLC1[m,2], freqLC2[m,2], freqNC[,2], freqNC1[,2], freqNC2[m,2] )
 
freq1 = plyr:: count( obj$predicted.celltype.l1[ obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$Sex=="Male"] )
freq2 = plyr:: count( obj$predicted.celltype.l1[ obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$Sex=="Female"] )
freq = plyr:: count( obj$predicted.celltype.l1 [obj$MajoritySinglet_Individual_Assignment != "unassigned"])
freqLC = plyr:: count( obj$predicted.celltype.l1 [obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$long.COVID=="Yes" ])
freqNC = plyr:: count( obj$predicted.celltype.l1 [obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$long.COVID=="No" ])
freqLC1 = plyr:: count( obj$predicted.celltype.l1 [obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$long.COVID=="Yes" & obj$Sex=="Male" ])
freqNC1 = plyr:: count( obj$predicted.celltype.l1 [obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$long.COVID=="No" & obj$Sex=="Male" ])
freqLC2 = plyr:: count( obj$predicted.celltype.l1 [obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$long.COVID=="Yes" & obj$Sex=="Female" ])
freqNC2 = plyr:: count( obj$predicted.celltype.l1 [obj$MajoritySinglet_Individual_Assignment != "unassigned" & obj$long.COVID=="No" & obj$Sex=="Female" ])
m = match(freq[,1] , freq2[,1])
freq_sex_cell.l1 = cbind(freq, freq1[,2], freq2[ ,2] ,freqLC[ ,2], freqLC1[ ,2], freqLC2[ ,2], freqNC[,2], freqNC1[,2], freqNC2[ ,2] )
 
save(freq_sex_cell,freq_sex_cell.l1, file="freq_sex_cell.Rdata" )

  
                    
