library(Seurat)
library(plyr)
library(viridis)

# Load in seurat object
immune.combined.sct <- readRDS("combined_all_SCT.rds") # Note, this takes ~13.1GB of RAM 

# Load metadata and attach to seurat object 
load("final_metadata.Rdata")
immune.combined.sct@meta.data = metadata 

# Load extra metadata information  
load("predicted.metadata_noVDJ.Rdata") 

# Build data filter  
## Remove doublets and unassigned cells  
filt = immune.combined.sct$Demuxlet_DropletType == "singlet"

# Filter/subset object
immune.combined.sct = immune.combined.sct[,filt]

# Run dim reduction and clustering 
immune.combined.sct <- RunPCA(immune.combined.sct, verbose = FALSE)
immune.combined.sct <- RunUMAP(immune.combined.sct, reduction = "pca", dims = 1:15)
immune.combined.sct <- FindNeighbors(immune.combined.sct, reduction = "pca", dims = 1:15)
immune.combined.sct <- FindClusters(immune.combined.sct, resolution = 0.5)


# Visualizations

## UMAP
p1 <- DimPlot(immune.combined.sct, reduction = "umap", group.by = "orig.ident")
p2 <- DimPlot(immune.combined.sct, reduction = "umap", label = TRUE, repel = TRUE)


